# PUBGy
[![Supported Versions](https://img.shields.io/pypi/pyversions/pubgy.svg)](https://pypi.org/project/PUBGy/)
[![PyPI Release](https://img.shields.io/pypi/v/pubgy.svg)](https://pypi.org/project/PUBGy/)
[![CodeFactor](https://www.codefactor.io/repository/github/discord-ian/pubgy/badge)](https://www.codefactor.io/repository/github/discord-ian/pubgy)

**Python Wrapper for interacting with the PUBG API**

*Not fully functional, but working with V17.1.0*
## Installation
Install / Update via pip
```
pip install -U pubgy
```
Building from source
```
git clone https://github.com/Discord-ian/pubgy.git
cd pubgy
python setup.py install
```
## Documentation

~~https://pubgy.discordian.dev~~

Documentation has not been completed, although it is on the way.

Reading the docstrings within the module would be the best way to approach it.
